@@ -14,15 +14,21 @@ const uiLanguages = [
   {
     "English": "en"
   },
+  {
+    "español": "es"
+  },
   {
     "suomi": "fi"
   },
   {
-    "français": "fr"
+    "Français": "fr"
   },
   {
     "עברית": "he"
   },
+  {
+    "हिन्दी": "hi"
+  },
   {
     "Հայերեն": "hy"
   },
@@ -47,9 +53,18 @@ const uiLanguages = [
   {
     "македонски": "mk"
   },
+  {
+    "Bahasa Melayu": "ms"
+  },
+  {
+    "Nederlands": "nl"
+  },
   {
     "ߒߞߏ": "nqo"
   },
+  {
+    "ଓଡ଼ିଆ": "or"
+  },
   {
     "Polski": "pl"
   },
@@ -62,12 +77,21 @@ const uiLanguages = [
   {
     "slovenčina": "sk"
   },
+  {
+    "سرائیکی": "skr-arab"
+  },
   {
     "slovenščina": "sl"
   },
+  {
+    "Shqip": "sq"
+  },
   {
     "Svenska": "sv"
   },
+  {
+    "ఇంగ్లీషు": "te"
+  },
   {
     "Türkçe": "tr"
   },
