@@ -301,20 +301,41 @@ TEST_F(LibraryServerTest, catalog_search_by_tag)
 
 TEST_F(LibraryServerTest, catalog_search_by_category)
 {
-  const auto r = zfs1_->GET("/ROOT%23%3F/catalog/search?category=jazz");
-  EXPECT_EQ(r->status, 200);
-  EXPECT_EQ(maskVariableOPDSFeedData(r->body),
-    OPDS_FEED_TAG
-    "  <id>12345678-90ab-cdef-1234-567890abcdef</id>\n"
-    "  <title>Filtered zims (category=jazz)</title>\n"
-    "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
-    "  <totalResults>1</totalResults>\n"
-    "  <startIndex>0</startIndex>\n"
-    "  <itemsPerPage>1</itemsPerPage>\n"
-    CATALOG_LINK_TAGS
-    CHARLES_RAY_CATALOG_ENTRY
-    "</feed>\n"
-  );
+
+  {
+    const auto r = zfs1_->GET("/ROOT%23%3F/catalog/search?category=jazz");
+    EXPECT_EQ(r->status, 200);
+    EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+      OPDS_FEED_TAG
+      "  <id>12345678-90ab-cdef-1234-567890abcdef</id>\n"
+      "  <title>Filtered zims (category=jazz)</title>\n"
+      "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+      "  <totalResults>1</totalResults>\n"
+      "  <startIndex>0</startIndex>\n"
+      "  <itemsPerPage>1</itemsPerPage>\n"
+      CATALOG_LINK_TAGS
+      CHARLES_RAY_CATALOG_ENTRY
+      "</feed>\n"
+    );
+  }
+
+  {
+    const auto r = zfs1_->GET("/ROOT%23%3F/catalog/search?category=jazz,wikipedia");
+    EXPECT_EQ(r->status, 200);
+    EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+      OPDS_FEED_TAG
+      "  <id>12345678-90ab-cdef-1234-567890abcdef</id>\n"
+      "  <title>Filtered zims (category=jazz%2Cwikipedia)</title>\n"
+      "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+      "  <totalResults>2</totalResults>\n"
+      "  <startIndex>0</startIndex>\n"
+      "  <itemsPerPage>2</itemsPerPage>\n"
+      CATALOG_LINK_TAGS
+      RAY_CHARLES_CATALOG_ENTRY
+      CHARLES_RAY_CATALOG_ENTRY
+      "</feed>\n"
+    );
+  }
 }
 
 TEST_F(LibraryServerTest, catalog_search_by_language)
@@ -793,6 +814,40 @@ TEST_F(LibraryServerTest, catalog_v2_entries_filtered_by_language)
   }
 }
 
+TEST_F(LibraryServerTest, catalog_v2_entries_filtered_by_category)
+{
+  {
+    const auto r = zfs1_->GET("/ROOT%23%3F/catalog/v2/entries?category=jazz");
+    EXPECT_EQ(r->status, 200);
+    EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+      CATALOG_V2_ENTRIES_PREAMBLE("?category=jazz")
+      "  <title>Filtered Entries (category=jazz)</title>\n"
+      "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+      "  <totalResults>1</totalResults>\n"
+      "  <startIndex>0</startIndex>\n"
+      "  <itemsPerPage>1</itemsPerPage>\n"
+      CHARLES_RAY_CATALOG_ENTRY
+      "</feed>\n"
+    );
+  }
+
+  {
+    const auto r = zfs1_->GET("/ROOT%23%3F/catalog/v2/entries?category=jazz,wikipedia");
+    EXPECT_EQ(r->status, 200);
+    EXPECT_EQ(maskVariableOPDSFeedData(r->body),
+      CATALOG_V2_ENTRIES_PREAMBLE("?category=jazz%2Cwikipedia")
+      "  <title>Filtered Entries (category=jazz%2Cwikipedia)</title>\n"
+      "  <updated>YYYY-MM-DDThh:mm:ssZ</updated>\n"
+      "  <totalResults>2</totalResults>\n"
+      "  <startIndex>0</startIndex>\n"
+      "  <itemsPerPage>2</itemsPerPage>\n"
+      RAY_CHARLES_CATALOG_ENTRY
+      CHARLES_RAY_CATALOG_ENTRY
+      "</feed>\n"
+    );
+  }
+}
+
 TEST_F(LibraryServerTest, catalog_v2_entries_multiple_filters)
 {
   {
@@ -973,7 +1028,12 @@ TEST_F(LibraryServerTest, no_name_mapper_catalog_v2_individual_entry_access)
   "    <title>Welcome to Kiwix Server</title>\n" \
   "    <link\n" \
   "      type=\"text/css\"\n" \
-  "      href=\"/ROOT%23%3F/skin/index.css?cacheid=e4d76d16\"\n" \
+  "      href=\"/ROOT%23%3F/skin/kiwix.css?cacheid=2158fad9\"\n" \
+  "      rel=\"Stylesheet\"\n" \
+  "    />\n" \
+  "    <link\n" \
+  "      type=\"text/css\"\n" \
+  "      href=\"/ROOT%23%3F/skin/index.css?cacheid=1e78e7cf\"\n" \
   "      rel=\"Stylesheet\"\n" \
   "    />\n" \
   "    <link rel=\"apple-touch-icon\" sizes=\"180x180\" href=\"/ROOT%23%3F/skin/favicon/apple-touch-icon.png?cacheid=f86f8df3\">\n" \
@@ -1090,7 +1150,7 @@ TEST_F(LibraryServerTest, no_name_mapper_catalog_v2_individual_entry_access)
   "    </div>\n" \
   "    <div id=\"kiwixfooter\" class=\"kiwixfooter\">Powered by&nbsp;<a href=\"https://kiwix.org\">Kiwix</a></div>\n" \
   "    </body>\n" \
-  "</html>"
+  "</html>\n"
 
 #define FILTERS_HTML(SELECTED_ENG) \
   "      <div class=\"kiwixNav__filters\">\n" \
