@@ -54,26 +54,28 @@ const ResourceCollection resources200Compressible{
   { DYNAMIC_CONTENT, "/ROOT%23%3F/viewer" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/viewer?cacheid=whatever" },
 
-  { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/autoComplete.min.js" },
-  { STATIC_CONTENT,  "/ROOT%23%3F/skin/autoComplete.min.js?cacheid=1191aaaf" },
-  { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/css/autoComplete.css" },
-  { STATIC_CONTENT,  "/ROOT%23%3F/skin/css/autoComplete.css?cacheid=08951e06" },
+  { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/autoComplete/autoComplete.min.js" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/autoComplete/autoComplete.min.js?cacheid=1191aaaf" },
+  { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/autoComplete/css/autoComplete.css" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/autoComplete/css/autoComplete.css?cacheid=ef30cd42" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/i18n.js" },
-  { STATIC_CONTENT,  "/ROOT%23%3F/skin/i18n.js?cacheid=2cf0f8c5" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/i18n.js?cacheid=6a8c6fb2" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/index.css" },
-  { STATIC_CONTENT,  "/ROOT%23%3F/skin/index.css?cacheid=e4d76d16" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/index.css?cacheid=1e78e7cf" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/index.js" },
-  { STATIC_CONTENT,  "/ROOT%23%3F/skin/index.js?cacheid=07b06fca" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/index.js?cacheid=ce19da2a" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/iso6391To3.js" },
   { STATIC_CONTENT,  "/ROOT%23%3F/skin/iso6391To3.js?cacheid=ecde2bb3" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/isotope.pkgd.min.js" },
   { STATIC_CONTENT,  "/ROOT%23%3F/skin/isotope.pkgd.min.js?cacheid=2e48d392" },
+  { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/kiwix.css" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/kiwix.css?cacheid=2158fad9" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/mustache.min.js" },
   { STATIC_CONTENT,  "/ROOT%23%3F/skin/mustache.min.js?cacheid=bd23c4fb" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/taskbar.css" },
-  { STATIC_CONTENT,  "/ROOT%23%3F/skin/taskbar.css?cacheid=bbdaf425" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/taskbar.css?cacheid=e014a885" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/viewer.js" },
-  { STATIC_CONTENT,  "/ROOT%23%3F/skin/viewer.js?cacheid=bb748367" },
+  { STATIC_CONTENT,  "/ROOT%23%3F/skin/viewer.js?cacheid=201653b8" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/fonts/Poppins.ttf" },
   { STATIC_CONTENT,  "/ROOT%23%3F/skin/fonts/Poppins.ttf?cacheid=af705837" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/fonts/Roboto.ttf" },
@@ -147,7 +149,7 @@ const ResourceCollection resources200Uncompressible{
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/search_results.css" },
   { STATIC_CONTENT,  "/ROOT%23%3F/skin/search_results.css?cacheid=76d39c84" },
   { DYNAMIC_CONTENT, "/ROOT%23%3F/skin/languages.js" },
-  { STATIC_CONTENT, "/ROOT%23%3F/skin/languages.js?cacheid=648526e1" },
+  { STATIC_CONTENT, "/ROOT%23%3F/skin/languages.js?cacheid=96f2cf73" },
 
   { ZIM_CONTENT,     "/ROOT%23%3F/raw/zimfile/meta/Title" },
   { ZIM_CONTENT,     "/ROOT%23%3F/raw/zimfile/meta/Description" },
@@ -274,7 +276,8 @@ TEST_F(ServerTest, CacheIdsOfStaticResources)
   const std::vector<UrlAndExpectedResult> testData{
     {
       /* url */ "/ROOT%23%3F/",
-R"EXPECTEDRESULT(      href="/ROOT%23%3F/skin/index.css?cacheid=e4d76d16"
+R"EXPECTEDRESULT(      href="/ROOT%23%3F/skin/kiwix.css?cacheid=2158fad9"
+      href="/ROOT%23%3F/skin/index.css?cacheid=1e78e7cf"
     <link rel="apple-touch-icon" sizes="180x180" href="/ROOT%23%3F/skin/favicon/apple-touch-icon.png?cacheid=f86f8df3">
     <link rel="icon" type="image/png" sizes="32x32" href="/ROOT%23%3F/skin/favicon/favicon-32x32.png?cacheid=79ded625">
     <link rel="icon" type="image/png" sizes="16x16" href="/ROOT%23%3F/skin/favicon/favicon-16x16.png?cacheid=a986fedc">
@@ -282,15 +285,19 @@ R"EXPECTEDRESULT(      href="/ROOT%23%3F/skin/index.css?cacheid=e4d76d16"
     <link rel="mask-icon" href="/ROOT%23%3F/skin/favicon/safari-pinned-tab.svg?cacheid=8d487e95" color="#5bbad5">
     <link rel="shortcut icon" href="/ROOT%23%3F/skin/favicon/favicon.ico?cacheid=92663314">
     <meta name="msapplication-config" content="/ROOT%23%3F/skin/favicon/browserconfig.xml?cacheid=f29a7c4a">
-        src: url("/ROOT%23%3F/skin/fonts/Poppins.ttf?cacheid=af705837") format("truetype");
-          src: url("/ROOT%23%3F/skin/fonts/Roboto.ttf?cacheid=84d10248") format("truetype");
-    <script type="module" src="/ROOT%23%3F/skin/i18n.js?cacheid=2cf0f8c5" defer></script>
-    <script type="text/javascript" src="/ROOT%23%3F/skin/languages.js?cacheid=648526e1" defer></script>
+    <script type="module" src="/ROOT%23%3F/skin/i18n.js?cacheid=6a8c6fb2" defer></script>
+    <script type="text/javascript" src="/ROOT%23%3F/skin/languages.js?cacheid=96f2cf73" defer></script>
     <script src="/ROOT%23%3F/skin/isotope.pkgd.min.js?cacheid=2e48d392" defer></script>
     <script src="/ROOT%23%3F/skin/iso6391To3.js?cacheid=ecde2bb3"></script>
-    <script type="text/javascript" src="/ROOT%23%3F/skin/index.js?cacheid=07b06fca" defer></script>
+    <script type="text/javascript" src="/ROOT%23%3F/skin/index.js?cacheid=ce19da2a" defer></script>
         <img src="/ROOT%23%3F/skin/feed.svg?cacheid=055b333f"
         <img src="/ROOT%23%3F/skin/langSelector.svg?cacheid=00b59961"
+)EXPECTEDRESULT"
+    },
+    {
+      /* url */ "/ROOT%23%3F/skin/kiwix.css",
+R"EXPECTEDRESULT(  src: url("../skin/fonts/Poppins.ttf?cacheid=af705837") format("truetype");
+  src: url("../skin/fonts/Roboto.ttf?cacheid=84d10248") format("truetype");
 )EXPECTEDRESULT"
     },
     {
@@ -308,15 +315,16 @@ R"EXPECTEDRESULT(                                <img src="${root}/skin/download
     },
     {
       /* url */ "/ROOT%23%3F/viewer",
-R"EXPECTEDRESULT(    <link type="text/css" href="./skin/taskbar.css?cacheid=bbdaf425" rel="Stylesheet" />
-    <link type="text/css" href="./skin/css/autoComplete.css?cacheid=08951e06" rel="Stylesheet" />
-    <script type="module" src="./skin/i18n.js?cacheid=2cf0f8c5" defer></script>
-    <script type="text/javascript" src="./skin/languages.js?cacheid=648526e1" defer></script>
-    <script type="text/javascript" src="./skin/viewer.js?cacheid=bb748367" defer></script>
-    <script type="text/javascript" src="./skin/autoComplete.min.js?cacheid=1191aaaf"></script>
+R"EXPECTEDRESULT(    <link type="text/css" href="./skin/kiwix.css?cacheid=2158fad9" rel="Stylesheet" />
+    <link type="text/css" href="./skin/taskbar.css?cacheid=e014a885" rel="Stylesheet" />
+    <link type="text/css" href="./skin/autoComplete/css/autoComplete.css?cacheid=ef30cd42" rel="Stylesheet" />
+    <script type="module" src="./skin/i18n.js?cacheid=6a8c6fb2" defer></script>
+    <script type="text/javascript" src="./skin/languages.js?cacheid=96f2cf73" defer></script>
+    <script type="text/javascript" src="./skin/viewer.js?cacheid=201653b8" defer></script>
+    <script type="text/javascript" src="./skin/autoComplete/autoComplete.min.js?cacheid=1191aaaf"></script>
       const blankPageUrl = root + "/skin/blank.html?cacheid=6b1fa032";
-            <img src="./skin/langSelector.svg?cacheid=00b59961">
           <label for="kiwix_button_show_toggle"><img src="./skin/caret.png?cacheid=22b942b4" alt=""></label>
+               src="./skin/langSelector.svg?cacheid=00b59961">
             src="./skin/blank.html?cacheid=6b1fa032" title="ZIM content" width="100%"
 )EXPECTEDRESULT"
     },
@@ -371,7 +379,7 @@ const char* urls404[] = {
   "/ROOT%23%3",
   "/ROOT%23%3Fxyz",
   "/ROOT%23%3F/skin/non-existent-skin-resource",
-  "/ROOT%23%3F/skin/autoComplete.min.js?cacheid=wrongcacheid",
+  "/ROOT%23%3F/skin/autoComplete/autoComplete.min.js?cacheid=wrongcacheid",
   "/ROOT%23%3F/catalog",
   "/ROOT%23%3F/catalog/",
   "/ROOT%23%3F/catalog/non-existent-item",
@@ -1056,15 +1064,21 @@ R"EXPECTEDRESPONSE(const uiLanguages = [
   {
     "English": "en"
   },
+  {
+    "español": "es"
+  },
   {
     "suomi": "fi"
   },
   {
-    "français": "fr"
+    "Français": "fr"
   },
   {
     "עברית": "he"
   },
+  {
+    "हिन्दी": "hi"
+  },
   {
     "Հայերեն": "hy"
   },
@@ -1089,9 +1103,18 @@ R"EXPECTEDRESPONSE(const uiLanguages = [
   {
     "македонски": "mk"
   },
+  {
+    "Bahasa Melayu": "ms"
+  },
+  {
+    "Nederlands": "nl"
+  },
   {
     "ߒߞߏ": "nqo"
   },
+  {
+    "ଓଡ଼ିଆ": "or"
+  },
   {
     "Polski": "pl"
   },
@@ -1104,12 +1127,21 @@ R"EXPECTEDRESPONSE(const uiLanguages = [
   {
     "slovenčina": "sk"
   },
+  {
+    "سرائیکی": "skr-arab"
+  },
   {
     "slovenščina": "sl"
   },
+  {
+    "Shqip": "sq"
+  },
   {
     "Svenska": "sv"
   },
+  {
+    "ఇంగ్లీషు": "te"
+  },
   {
     "Türkçe": "tr"
   },
@@ -1130,7 +1162,6 @@ TEST_F(ServerTest, UserLanguageControl)
     const std::string url;
     const std::string acceptLanguageHeader;
     const char* const requestCookie; // Cookie: header of the request
-    const char* const responseSetCookie; // Set-Cookie: header of the response
     const std::string expectedH1;
 
     operator TestContext() const
@@ -1157,7 +1188,6 @@ TEST_F(ServerTest, UserLanguageControl)
       /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article",
       /*Accept-Language:*/ "",
       /*Request Cookie:*/       NO_COOKIE,
-      /*Response Set-Cookie:*/  "userlang=en;Path=/ROOT%23%3F;Max-Age=31536000",
       /* expected <h1> */ "Not Found"
     },
     {
@@ -1165,7 +1195,6 @@ TEST_F(ServerTest, UserLanguageControl)
       /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article?userlang=en",
       /*Accept-Language:*/ "",
       /*Request Cookie:*/       NO_COOKIE,
-      /*Response Set-Cookie:*/  "userlang=en;Path=/ROOT%23%3F;Max-Age=31536000",
       /* expected <h1> */ "Not Found"
     },
     {
@@ -1173,7 +1202,6 @@ TEST_F(ServerTest, UserLanguageControl)
       /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article?userlang=test",
       /*Accept-Language:*/ "",
       /*Request Cookie:*/       NO_COOKIE,
-      /*Response Set-Cookie:*/  "userlang=test;Path=/ROOT%23%3F;Max-Age=31536000",
       /* expected <h1> */ "[I18N TESTING] Content not found, but at least the server is alive"
     },
     {
@@ -1181,7 +1209,6 @@ TEST_F(ServerTest, UserLanguageControl)
       /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article",
       /*Accept-Language:*/ "*",
       /*Request Cookie:*/       NO_COOKIE,
-      /*Response Set-Cookie:*/  "userlang=en;Path=/ROOT%23%3F;Max-Age=31536000",
       /* expected <h1> */ "Not Found"
     },
     {
@@ -1189,71 +1216,20 @@ TEST_F(ServerTest, UserLanguageControl)
       /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article",
       /*Accept-Language:*/ "test",
       /*Request Cookie:*/       NO_COOKIE,
-      /*Response Set-Cookie:*/  "userlang=test;Path=/ROOT%23%3F;Max-Age=31536000",
       /* expected <h1> */ "[I18N TESTING] Content not found, but at least the server is alive"
     },
     {
-      "userlang cookie is respected",
+      "userlang cookie is ignored",
       /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article",
       /*Accept-Language:*/ "",
       /*Request Cookie:*/       "userlang=test",
-      /*Response Set-Cookie:*/  NO_COOKIE,
-      /* expected <h1> */ "[I18N TESTING] Content not found, but at least the server is alive"
-    },
-    {
-      "userlang cookie is correctly parsed",
-      /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article",
-      /*Accept-Language:*/ "",
-      /*Request Cookie:*/       "anothercookie=123; userlang=test",
-      /*Response Set-Cookie:*/  NO_COOKIE,
-      /* expected <h1> */ "[I18N TESTING] Content not found, but at least the server is alive"
-    },
-    {
-      "userlang cookie is correctly parsed",
-      /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article",
-      /*Accept-Language:*/ "",
-      /*Request Cookie:*/       "userlang=test; anothercookie=abc",
-      /*Response Set-Cookie:*/  NO_COOKIE,
-      /* expected <h1> */ "[I18N TESTING] Content not found, but at least the server is alive"
-    },
-    {
-      "userlang cookie is correctly parsed",
-      /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article",
-      /*Accept-Language:*/ "",
-      /*Request Cookie:*/       "cookie1=abc; userlang=test; cookie2=xyz",
-      /*Response Set-Cookie:*/  NO_COOKIE,
-      /* expected <h1> */ "[I18N TESTING] Content not found, but at least the server is alive"
-    },
-    {
-      "Multiple userlang cookies are not a problem",
-      /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article",
-      /*Accept-Language:*/ "",
-      /*Request Cookie:*/       "cookie1=abc; userlang=en; userlang=test; cookie2=xyz",
-      /*Response Set-Cookie:*/  NO_COOKIE,
-      /* expected <h1> */ "[I18N TESTING] Content not found, but at least the server is alive"
+      /* expected <h1> */ "Not Found"
     },
     {
       "userlang query parameter takes precedence over Accept-Language",
       /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article?userlang=en",
       /*Accept-Language:*/ "test",
       /*Request Cookie:*/       NO_COOKIE,
-      /*Response Set-Cookie:*/  "userlang=en;Path=/ROOT%23%3F;Max-Age=31536000",
-      /* expected <h1> */ "Not Found"
-    },
-    {
-      "userlang query parameter takes precedence over its cookie counterpart",
-      /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article?userlang=en",
-      /*Accept-Language:*/ "",
-      /*Request Cookie:*/       "userlang=test",
-      /*Response Set-Cookie:*/  "userlang=en;Path=/ROOT%23%3F;Max-Age=31536000",
-      /* expected <h1> */ "Not Found"
-    },
-    {
-      "userlang in cookies takes precedence over Accept-Language",
-      /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article",
-      /*Accept-Language:*/ "test",
-      /*Request Cookie:*/       "userlang=en",
-      /*Response Set-Cookie:*/  NO_COOKIE,
       /* expected <h1> */ "Not Found"
     },
     {
@@ -1263,7 +1239,6 @@ TEST_F(ServerTest, UserLanguageControl)
       /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article",
       /*Accept-Language:*/ "test;q=0.9, en;q=0.2",
       /*Request Cookie:*/       NO_COOKIE,
-      /*Response Set-Cookie:*/  "userlang=test;Path=/ROOT%23%3F;Max-Age=31536000",
       /* expected <h1> */ "[I18N TESTING] Content not found, but at least the server is alive"
     },
     {
@@ -1273,7 +1248,6 @@ TEST_F(ServerTest, UserLanguageControl)
       /*url*/ "/ROOT%23%3F/content/zimfile/invalid-article",
       /*Accept-Language:*/ "test;q=0.2, en;q=0.9",
       /*Request Cookie:*/       NO_COOKIE,
-      /*Response Set-Cookie:*/  "userlang=en;Path=/ROOT%23%3F;Max-Age=31536000",
       /* expected <h1> */ "Not Found"
     },
   };
@@ -1289,12 +1263,7 @@ TEST_F(ServerTest, UserLanguageControl)
       headers.insert({"Cookie", t.requestCookie});
     }
     const auto r = zfs1_->GET(t.url.c_str(), headers);
-    if ( t.responseSetCookie ) {
-      ASSERT_TRUE(r->has_header("Set-Cookie")) << t;
-      EXPECT_EQ(t.responseSetCookie, getHeaderValue(r->headers, "Set-Cookie")) << t;
-    } else {
-      EXPECT_FALSE(r->has_header("Set-Cookie"));
-    }
+    EXPECT_FALSE(r->has_header("Set-Cookie"));
     std::regex_search(r->body, h1Match, h1Regex);
     const std::string h1(h1Match[1]);
     EXPECT_EQ(h1, t.expectedH1) << t;
@@ -1989,7 +1958,8 @@ TEST_F(ServerTest, viewerSettings)
 R"(const viewerSettings = {
   toolbarEnabled:       false,
   linkBlockingEnabled:  false,
-  libraryButtonEnabled: false
+  libraryButtonEnabled: false,
+  defaultUserLanguage:  "en"
 }
 )");
   }
@@ -2000,7 +1970,8 @@ R"(const viewerSettings = {
 R"(const viewerSettings = {
   toolbarEnabled:       false,
   linkBlockingEnabled:  true,
-  libraryButtonEnabled: false
+  libraryButtonEnabled: false,
+  defaultUserLanguage:  "en"
 }
 )");
   }
@@ -2011,7 +1982,8 @@ R"(const viewerSettings = {
 R"(const viewerSettings = {
   toolbarEnabled:       true,
   linkBlockingEnabled:  false,
-  libraryButtonEnabled: false
+  libraryButtonEnabled: false,
+  defaultUserLanguage:  "en"
 }
 )");
   }
@@ -2022,7 +1994,47 @@ R"(const viewerSettings = {
 R"(const viewerSettings = {
   toolbarEnabled:       true,
   linkBlockingEnabled:  false,
-  libraryButtonEnabled: true
+  libraryButtonEnabled: true,
+  defaultUserLanguage:  "en"
+}
+)");
+  }
+
+  {
+    resetServer(ZimFileServer::WITH_TASKBAR_AND_LIBRARY_BUTTON);
+    const Headers headers{ {"Accept-Language", "fr"} };
+    ASSERT_EQ(zfs1_->GET("/ROOT%23%3F/viewer_settings.js", headers)->body,
+R"(const viewerSettings = {
+  toolbarEnabled:       true,
+  linkBlockingEnabled:  false,
+  libraryButtonEnabled: true,
+  defaultUserLanguage:  "fr"
+}
+)");
+  }
+
+  {
+    resetServer(ZimFileServer::WITH_TASKBAR_AND_LIBRARY_BUTTON);
+    const Headers headers{ {"Accept-Language", "test;q=0.2, en;q=0.9"} };
+    ASSERT_EQ(zfs1_->GET("/ROOT%23%3F/viewer_settings.js", headers)->body,
+R"(const viewerSettings = {
+  toolbarEnabled:       true,
+  linkBlockingEnabled:  false,
+  libraryButtonEnabled: true,
+  defaultUserLanguage:  "en"
+}
+)");
+  }
+
+  {
+    resetServer(ZimFileServer::WITH_TASKBAR_AND_LIBRARY_BUTTON);
+    const Headers headers{ {"Accept-Language", "test;q=0.9, en;q=0.2"} };
+    ASSERT_EQ(zfs1_->GET("/ROOT%23%3F/viewer_settings.js", headers)->body,
+R"(const viewerSettings = {
+  toolbarEnabled:       true,
+  linkBlockingEnabled:  false,
+  libraryButtonEnabled: true,
+  defaultUserLanguage:  "test"
 }
 )");
   }
